==> connector-service-1.0.0-20200323.073148-168-sources.jar: com/bizvane/connectorservice/entity/common/DebitCardConsumeRequestVo.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @author xz
 * @date 2019/12/19 15:19
 **/


public class DebitCardConsumeRequestVo extends BaseModel {
    /**
     * 储蓄卡号
     */
    private String debitCardNo;

    /**
     * 会员卡号
     */
    private String memberCardCode;

    /**
     * 会员code
     */
    private String memberCode;

    /**
     * 变更本金金额
     */
    private BigDecimal changeAmount;

    /**
     * 变更赠送金额
     */
    private BigDecimal changeGiveAmount;

    /**
     * 订单号
     */
    private String orderNo;

    /**
     * 操作人code
     */
    private String userCode;

    /**
     * 类型 1:订单退货  4:消费订单',
     */
    private Integer type;

    /**
     * 下单时间
     */
    @DateTimeFormat( pattern="yyyy-MM-dd HH:mm:ss")
    private Date orderTime;

    public String getDebitCardNo() {
        return debitCardNo;
    }

    public void setDebitCardNo(String debitCardNo) {
        this.debitCardNo = debitCardNo;
    }

    public String getMemberCardCode() {
        return memberCardCode;
    }

    public void setMemberCardCode(String memberCardCode) {
        this.memberCardCode = memberCardCode;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public BigDecimal getChangeAmount() {
        return changeAmount;
    }

    public void setChangeAmount(BigDecimal changeAmount) {
        this.changeAmount = changeAmount;
    }

    public BigDecimal getChangeGiveAmount() {
        return changeGiveAmount;
    }

    public void setChangeGiveAmount(BigDecimal changeGiveAmount) {
        this.changeGiveAmount = changeGiveAmount;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Date getOrderTime() {
        return orderTime;
    }

    public void setOrderTime(Date orderTime) {
        this.orderTime = orderTime;
    }
}

==> connector-service-1.0.2-20201110.033846-27-sources.jar: com/bizvane/connectorservice/entity/common/DebitCardConsumeRequestVo.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @author xz
 * @date 2019/12/19 15:19
 **/


public class DebitCardConsumeRequestVo extends BaseModel {
    /**
     * 储蓄卡号
     */
    private String debitCardNo;

    /**
     * 会员卡号
     */
    private String memberCardCode;

    /**
     * 会员code
     */
    private String memberCode;

    /**
     * 变更本金金额
     */
    private BigDecimal changeAmount;

    /**
     * 变更赠送金额
     */
    private BigDecimal changeGiveAmount;

    /**
     * 订单号
     */
    private String orderNo;

    /**
     * 操作人code
     */
    private String userCode;

    /**
     * 类型 1:订单退货  4:消费订单',
     */
    private Integer type;

    /**
     * 下单时间
     */
    @DateTimeFormat( pattern="yyyy-MM-dd HH:mm:ss")
    private Date orderTime;

    /**
     * 储值卡余额调整接口标志
     * */
    private String flagInterface;

    public String getFlagInterface() {
        return flagInterface;
    }

    public void setFlagInterface(String flagInterface) {
        this.flagInterface = flagInterface;
    }

    public String getDebitCardNo() {
        return debitCardNo;
    }

    public void setDebitCardNo(String debitCardNo) {
        this.debitCardNo = debitCardNo;
    }

    public String getMemberCardCode() {
        return memberCardCode;
    }

    public void setMemberCardCode(String memberCardCode) {
        this.memberCardCode = memberCardCode;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public BigDecimal getChangeAmount() {
        return changeAmount;
    }

    public void setChangeAmount(BigDecimal changeAmount) {
        this.changeAmount = changeAmount;
    }

    public BigDecimal getChangeGiveAmount() {
        return changeGiveAmount;
    }

    public void setChangeGiveAmount(BigDecimal changeGiveAmount) {
        this.changeGiveAmount = changeGiveAmount;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Date getOrderTime() {
        return orderTime;
    }

    public void setOrderTime(Date orderTime) {
        this.orderTime = orderTime;
    }
}
